@@ -1,53 +1,92 @@
 #!/sjr/beodata/local/python_linux/bin/python
+"""A collection of filling routines."""
 
 from __future__ import print_function
 from __future__ import absolute_import
 
 import pandas as pd
-from numpy import *
 import mando
+from mando.rst_text_formatter import RSTHelpFormatter
 
 from . import tsutils
 
 
-@mando.command
-def fill(method='ffill', interval='guess', print_input=False,  input_ts='-'):
-    '''
-    Fills missing values (NaN) with different methods.  Missing values can
-        occur because of NaN, or because the time series is sparse.  The
-        'interval' option can insert NaNs to create a dense time series.
+@mando.command(formatter_class=RSTHelpFormatter, doctype='numpy')
+@tsutils.doc(tsutils.docstrings)
+def fill(method='ffill',
+         interval='guess',
+         print_input=False,
+         input_ts='-',
+         start_date=None,
+         end_date=None,
+         columns=None):
+    """Fill missing values (NaN) with different methods.
 
-    :param method: String contained in single quotes or a number that
+    Missing values can occur because of NaN, or because the time series
+    is sparse.  The 'interval' option can insert NaNs to create a dense
+    time series.
+
+    Parameters
+    ----------
+    method : str
+        String contained in single quotes or a number that
         defines the method to use for filling.
-        'ffill': assigns NaN values to the last good value
-        'bfill': assigns NaN values to the next good value
-                 number: fills all NaN to this number
-        'linear': will linearly interpolate missing values
-        'spline': spline interpolation
-        'nearest': nearest good value
-        'zero':
-        'slinear':
-        'quadratic':
-        'cubic':
-        'mean': fill with mean
-        'median': fill with median
-        'max': fill with maximum
-        'min': fill with minimum
+
+        +-----------+---------------------------+
+        | ffill     | assigns NaN values to     |
+        |           | the last good value       |
+        +-----------+---------------------------+
+        | bfill     | assigns NaN values to     |
+        |           | the next good value       |
+        +-----------+---------------------------+
+        | 2.3       | any number: fills all NaN |
+        |           | with this number          |
+        +-----------+---------------------------+
+        | linear    | will linearly interpolate |
+        |           | missing values            |
+        +-----------+---------------------------+
+        | spline    | spline interpolation      |
+        +-----------+---------------------------+
+        | nearest   | nearest good value        |
+        +-----------+---------------------------+
+        | zero      |                           |
+        +-----------+---------------------------+
+        | slinear   |                           |
+        +-----------+---------------------------+
+        | quadratic |                           |
+        +-----------+---------------------------+
+        | cubic     |                           |
+        +-----------+---------------------------+
+        | mean      | fill with mean            |
+        +-----------+---------------------------+
+        | median    | fill with median          |
+        +-----------+---------------------------+
+        | max       | fill with maximum         |
+        +-----------+---------------------------+
+        | min       | fill with minimum         |
+        +-----------+---------------------------+
+
         If a number will fill with that number.
-    :param interval: Will try to insert missing intervals.  Can give any
+    interval : str
+        Will try to insert missing intervals.  Can give any
         of the pandas offset aliases, 'guess' (to try and figure the
         interval), or None to not insert missing intervals.
-    :param -p, --print_input: If set to 'True' will include the input columns in the
-        output table.  Default is 'False'.
-    :param -i, --input_ts <str>: Filename with data in 'ISOdate,value' format or '-' for
-        stdin.
-    '''
-    tsd = tsutils.read_iso_ts(input_ts)
+    {print_input}
+    {input_ts}
+    {start_date}
+    {end_date}
+    {columns}
+
+    """
+    tsd = tsutils.common_kwds(tsutils.read_iso_ts(input_ts, dropna='all'),
+                              start_date=start_date,
+                              end_date=end_date,
+                              pick=columns)
     if print_input is True:
         ntsd = tsd.copy()
     else:
         ntsd = tsd
-    ntsd = tsutils.asbestfreq(ntsd)[0]
+    ntsd = tsutils.asbestfreq(ntsd)
     offset = ntsd.index[1] - ntsd.index[0]
     predf = pd.DataFrame(dict(zip(tsd.columns, tsd.mean().values)),
                          index=[tsd.index[0] - offset])
@@ -77,14 +116,20 @@ def fill(method='ffill', interval='guess', print_input=False,  input_ts='-'):
         try:
             ntsd = ntsd.fillna(value=float(method))
         except ValueError:
-            pass
+            raise ValueError("""
+*
+*   The allowable values for 'method' are 'ffill', 'bfill', 'linear',
+*   'nearest', 'zero', 'slinear', 'quadratic', 'cubic', 'mean', 'median',
+*   'max', 'min' or a number.  Instead you have {0}.
+*
+""".format(method))
     ntsd = ntsd.iloc[1:-1]
     tsd.index.name = 'Datetime'
     ntsd.index.name = 'Datetime'
     return tsutils.print_input(print_input, tsd, ntsd, '_fill')
 
 
-#@mando.command
+#@mando.command(formatter_class=RSTHelpFormatter)
 def fill_by_correlation(method='move2',
                         maximum_lag=0,
                         interval='guess',
@@ -92,27 +137,29 @@ def fill_by_correlation(method='move2',
                         choose_best='dtw',
                         print_input=False,
                         input_ts='-'):
-    '''
-    Fills missing values (NaN) with different methods.  Missing values can
-        occur because of NaN, or because the time series is sparse.  The
-        'interval' option can insert NaNs to create a dense time series.
+    """Fill missing values (NaN) with different methods.
+
+    Missing values can occur because of NaN, or because the time series
+    is sparse.  The 'interval' option can insert NaNs to create a dense
+    time series.
+
     :param method: String contained in single quotes or a number that
-        defines the method to use for filling.
-        'move2': maintenance of variance extension - 2
+        defines the method to use for filling.  'move2': maintenance of
+        variance extension - 2
     :param interval: Will try to insert missing intervals.  Can give any
         of the pandas offset aliases, 'guess' (to try and figure the
         interval), or None to not insert missing intervals.
-    :param -p, --print_input: If set to 'True' will include the input columns in the
-        output table.  Default is 'False'.
-    :param -i, --input_ts <str>: Filename with data in 'ISOdate,value' format or '-' for
-        stdin.
-    '''
+    :param -p, --print_input: If set to 'True' will include the input
+        columns in the output table.  Default is 'False'.
+    :param -i, --input_ts <str>: Filename with data in 'ISOdate,value'
+        format or '-' for stdin.
+    """
     tsd = tsutils.read_iso_ts(input_ts)
     if print_input is True:
         ntsd = tsd.copy()
     else:
         ntsd = tsd
-    ntsd = tsutils.asbestfreq(ntsd)[0]
+    ntsd = tsutils.asbestfreq(ntsd)
 
     if transform == 'log10':
         ntsd = pd.np.log10(ntsd)
@@ -135,14 +182,14 @@ def fill_by_correlation(method='move2',
     single_source_ts = ['move1', 'move2', 'move3']
     if method.lower() in single_source_ts:
         if len(basets.columns) != 1:
-            raise ValueError('''
+            raise ValueError("""
 *
 *   For methods in {0}
 *   You can only have a single source column.  You can pass in onlu 2
 *   time-series or use the flag 'choose_best' along with 'maximum_lag'.
 *   Instead there are {1} source time series.
 *
-'''.format(single_source_ts, len(basets.columns)))
+""".format(single_source_ts, len(basets.columns)))
 
     if method == 'move1':
         ntsd = firstcol.join(basets)
