@@ -1,3 +1,4 @@
+"""Collection of peak detection algorithms."""
 
 from __future__ import print_function
 
@@ -6,8 +7,7 @@ import numpy as np
 
 def _boolrelextrema(data, comparator,
                     axis=0, order=1, mode='clip'):
-    """
-    Calculate the relative extrema of `data`.
+    """Calculate the relative extrema of `data`.
 
     Relative extrema are calculated by finding locations where
     comparator(data[n],data[n+1:n+order+1]) = True.
@@ -46,8 +46,7 @@ def _boolrelextrema(data, comparator,
     >>> _boolrelextrema(testdata, np.greater, axis=0)
     array([False, False,  True, False, False], dtype=bool)
     """
-
-    if((int(order) != order) or (order < 1)):
+    if (int(order) != order) or (order < 1):
         raise ValueError('Order must be an int >= 1')
 
     datalen = data.shape[axis]
@@ -60,20 +59,20 @@ def _boolrelextrema(data, comparator,
         results &= comparator(main, plus)
         minus = np.take(data, locs - shift, axis=axis, mode=mode)
         results &= comparator(main, minus)
-        if(~results.any()):
+        if ~results.any():
             return results
     return results
 
 
 def _argrel(data, axis=0, window=1):
+    """Private function to find relative min and max of data."""
     tmpmin = _argrelmin(data, axis=axis, order=window)
     tmpmax = _argrelmax(data, axis=axis, order=window)
     return (zip(tmpmax[0], data[tmpmax[0]]), zip(tmpmin[0], data[tmpmin[0]]))
 
 
 def _argrelmin(data, axis=0, order=1, mode='clip'):
-    """
-    Calculate the relative minima of `data`.
+    """Calculate the relative minima of `data`.
 
     See also
     --------
@@ -83,8 +82,7 @@ def _argrelmin(data, axis=0, order=1, mode='clip'):
 
 
 def _argrelmax(data, axis=0, order=1, mode='clip'):
-    """
-    Calculate the relative maxima of `data`.
+    """Calculate the relative maxima of `data`.
 
     See also
     --------
@@ -95,8 +93,7 @@ def _argrelmax(data, axis=0, order=1, mode='clip'):
 
 def _argrelextrema(data, comparator,
                    axis=0, order=1, mode='clip'):
-    """
-    Calculate the relative extrema of `data`
+    """Calculate the relative extrema of `data`.
 
     Returns
     -------
@@ -118,11 +115,17 @@ def _argrelextrema(data, comparator,
 
 
 def _datacheck_peakdetect(x_axis, y_axis):
+    """Check x and y axis, creating an x data_set if necessary."""
     if x_axis is None:
         x_axis = range(len(y_axis))
 
     if len(y_axis) != len(x_axis):
-        raise ValueError
+        raise ValueError("""
+*
+*   The length of y values must equal the length of x values.  Instead the
+*   length of y values is {0} and the length of x values is {1}.
+*
+""".format(len(y_axis), len(x_axis)))
 
     # needs to be a numpy array
     y_axis = np.array(y_axis)
@@ -131,8 +134,7 @@ def _datacheck_peakdetect(x_axis, y_axis):
 
 
 def _peakdetect_parabola_fitter(raw_peaks, x_axis, y_axis, points):
-    """
-    Performs the actual parabola fitting for the _peakdetect_parabola function.
+    """Perform parabola fitting for the _peakdetect_parabola function.
 
     keyword arguments:
     raw_peaks -- A list of either the maximium or the minimum peaks, as given
@@ -144,10 +146,12 @@ def _peakdetect_parabola_fitter(raw_peaks, x_axis, y_axis, points):
 
     return -- A list giving all the peaks and the fitted waveform, format:
         [[x, y, [fitted_x, fitted_y]]]
-
     """
     from scipy.optimize import curve_fit
-    func = lambda x, k, tau, m: k * ((x - tau) ** 2) + m
+
+    def func(x, k, tau, m):
+        return k * ((x - tau) ** 2) + m
+
     fitted_peaks = []
     for peak in raw_peaks:
         index = peak[0]
@@ -161,7 +165,7 @@ def _peakdetect_parabola_fitter(raw_peaks, x_axis, y_axis, points):
         # build list of approximations
         # k = -m as first approximation?
         p0 = (-m, tau, m)
-        popt, pcov = curve_fit(func, x_data, y_data, p0)
+        popt, _ = curve_fit(func, x_data, y_data, p0)
         # retrieve tau and m i.e x and y value of peak
         x, y = popt[1:3]
 
@@ -175,9 +179,10 @@ def _peakdetect_parabola_fitter(raw_peaks, x_axis, y_axis, points):
 
 
 def _peakdetect(y_axis, x_axis=None, window=24, delta=0):
-    """
-    Converted from/based on a MATLAB script at:
-    http://billauer.co.il/peakdet.html
+    """Private peak detection algorithm.
+
+    Converted from/based on a MATLAB script
+    at:http://billauer.co.il/peakdet.html
 
     function for detecting local maximas and minmias in a signal.
     Discovers peaks by searching for values which are surrounded by lower
@@ -225,7 +230,7 @@ def _peakdetect(y_axis, x_axis=None, window=24, delta=0):
     # mx and mn respectively
     mn, mx = np.Inf, -np.Inf
 
-    #Only detect peak if there is 'window' amount of points after it
+    # Only detect peak if there is 'window' amount of points after it
     for index, (x, y) in enumerate(zip(x_axis[:-window],
                                        y_axis[:-window])):
         if y > mx:
@@ -235,7 +240,7 @@ def _peakdetect(y_axis, x_axis=None, window=24, delta=0):
             mn = y
             mnpos = x
 
-        ####look for max####
+        # ####look for max####
         if y < mx-delta and mx != np.Inf:
             # Maxima peak candidate found
             # look ahead in signal to ensure that this is a peak and not jitter
@@ -246,11 +251,11 @@ def _peakdetect(y_axis, x_axis=None, window=24, delta=0):
                 mx = np.Inf
                 mn = np.Inf
                 if index+window >= length:
-                    #end is within window no more peaks can be found
+                    # end is within window no more peaks can be found
                     break
                 continue
 
-        ####look for min####
+        # ####look for min####
         if y > mn+delta and mn != -np.Inf:
             # Minima peak candidate found
             # look ahead in signal to ensure that this is a peak and not jitter
@@ -261,7 +266,7 @@ def _peakdetect(y_axis, x_axis=None, window=24, delta=0):
                 mn = -np.Inf
                 mx = -np.Inf
                 if index+window >= length:
-                    #end is within window no more peaks can be found
+                    # end is within window no more peaks can be found
                     break
 
     # Remove the false hit on the first value of the y_axis
@@ -279,7 +284,8 @@ def _peakdetect(y_axis, x_axis=None, window=24, delta=0):
 
 
 def _peakdetect_fft(y_axis, x_axis, pad_len=5):
-    """
+    """Private function to calculate FFT peak detection.
+
     Performs a FFT calculation on the data and zero-pads the results to
     increase the time domain resolution after performing the inverse fft and
     send the data to the '_peakdetect' function for peak
@@ -333,8 +339,13 @@ def _peakdetect_fft(y_axis, x_axis, pad_len=5):
         fft_data = fft(y_axis)
     else:
         fft_data = fft(y_axis[zero_indices[0]:zero_indices[last_indice]])
-    padd = lambda x, c: x[:len(x) // 2] + [0] * c + x[len(x) // 2:]
-    n = lambda x: (np.log(x) / np.log(2)).astype('i') + 1
+
+    def padd(x, c):
+        return x[:len(x) // 2] + [0] * c + x[len(x) // 2:]
+
+    def n(x):
+        return (np.log(x) / np.log(2)).astype('i') + 1
+
     # padds to 2**n amount of samples
     fft_padded = padd(list(fft_data), 2 **
                       n(len(fft_data) * pad_len) - len(fft_data))
@@ -357,7 +368,8 @@ def _peakdetect_fft(y_axis, x_axis, pad_len=5):
 
 
 def _peakdetect_parabola(y_axis, x_axis, points=9):
-    """
+    """Private function for parabola peak detection.
+
     Function for detecting local maximas and minmias in a signal.
     Discovers peaks by fitting the model function: y = k (x - tau) ** 2 + m
     to the peaks. The amount of points used in the fitting is set by the
@@ -400,15 +412,16 @@ def _peakdetect_parabola(y_axis, x_axis, points=9):
     min_ = _peakdetect_parabola_fitter(min_raw, x_axis, y_axis, points)
 
     max_peaks = map(lambda x: [x[0], x[1]], max_)
-    max_fitted = map(lambda x: x[-1], max_)
+    # max_fitted = map(lambda x: x[-1], max_)
     min_peaks = map(lambda x: [x[0], x[1]], min_)
-    min_fitted = map(lambda x: x[-1], min_)
+    # min_fitted = map(lambda x: x[-1], min_)
 
     return [max_peaks, min_peaks]
 
 
 def _peakdetect_sine(y_axis, x_axis, points=9, lock_frequency=False):
-    """
+    """Private function for sine wave based peak detection.
+
     Function for detecting local maximas and minmias in a signal.
     Discovers peaks by fitting the model function:
     y = A * sin(2 * pi * f * x - tau) to the peaks. The amount of points used
@@ -473,11 +486,15 @@ def _peakdetect_sine(y_axis, x_axis, points=9, lock_frequency=False):
     # if cosine is used then tau could equal the x position of the peak
     # if sine were to be used then tau would be the first zero crossing
     if lock_frequency:
-        func = lambda x, A, tau: A * np.sin(
-            2 * np.pi * Hz * (x - tau) + np.pi / 2)
+        # This is strange - only difference in the two "func"
+        # definitions is the "Hz" argument
+
+        def func(x, A, tau):
+            return A * np.sin(2 * np.pi * Hz * (x - tau) + np.pi / 2)
     else:
-        func = lambda x, A, Hz, tau: A * np.sin(
-            2 * np.pi * Hz * (x - tau) + np.pi / 2)
+
+        def func(x, A, Hz, tau):
+            return A * np.sin(2 * np.pi * Hz * (x - tau) + np.pi / 2)
     # func = lambda x, A, Hz, tau: A * np.cos(2 * np.pi * Hz * (x - tau))
 
     # get peaks
@@ -501,7 +518,7 @@ def _peakdetect_sine(y_axis, x_axis, points=9, lock_frequency=False):
 
             # subtract offset from waveshape
             y_data -= offset
-            popt, pcov = curve_fit(func, x_data, y_data, p0)
+            popt, _ = curve_fit(func, x_data, y_data, p0)
             # retrieve tau and A i.e x and y value of peak
             x = popt[-1]
             y = popt[0]
@@ -521,15 +538,16 @@ def _peakdetect_sine(y_axis, x_axis, points=9, lock_frequency=False):
 
     # structure date for output
     max_peaks = map(lambda x: [x[0], x[1]], fitted_peaks[0])
-    max_fitted = map(lambda x: x[-1], fitted_peaks[0])
+    # max_fitted = map(lambda x: x[-1], fitted_peaks[0])
     min_peaks = map(lambda x: [x[0], x[1]], fitted_peaks[1])
-    min_fitted = map(lambda x: x[-1], fitted_peaks[1])
+    # min_fitted = map(lambda x: x[-1], fitted_peaks[1])
 
     return [max_peaks, min_peaks]
 
 
 def _peakdetect_sine_locked(y_axis, x_axis, points=9):
-    """
+    """Private function for peak detection with locked sine wave.
+
     Convinience function for calling the '_peakdetect_sine' function with
     the lock_frequency argument as True.
 
@@ -546,29 +564,30 @@ def _peakdetect_sine_locked(y_axis, x_axis, points=9):
 
 
 def _peakdetect_zero_crossing(y_axis, x_axis=None, window=5):
-    """
+    """Private function for zero crossing peak detection.
+
     Function for detecting local maximas and minmias in a signal.
     Discovers peaks by dividing the signal into bins and retrieving the
     maximum and minimum value of each the even and odd bins respectively.
     Division into bins is performed by smoothing the curve and finding the
     zero crossings.
 
-    Suitable for repeatable signals, where some noise is tolerated. Excecutes
+    Suitable for repeatable signals, where some noise is tolerated. Executes
     faster than '_peakdetect', although this function will break if the offset
     of the signal is too large. It should also be noted that the first and
     last peak will probably not be found, as this function only can find peaks
     between the first and last zero crossing.
 
     keyword arguments:
-    y_axis -- A list containg the signal over which to find peaks
+    y_axis -- A list containing the signal over which to find peaks
     x_axis -- (optional) A x-axis whose values correspond to the y_axis list
-        and is used in the return to specify the postion of the peaks. If
+        and is used in the return to specify the position of the peaks. If
         omitted an index of the y_axis is used. (default: None)
     window -- the dimension of the smoothing window; should be an odd integer
         (default: 11)
 
     return -- two lists [max_peaks, min_peaks] containing the positive and
-        negative peaks respectively. Each cell of the lists contains a tupple
+        negative peaks respectively. Each cell of the lists contains a tuple
         of: (position, peak_value)
         to get the average peak value do: np.mean(max_peaks, 0)[1] on the
         results to unpack one of the lists into x, y coordinates do:
@@ -621,8 +640,7 @@ def _peakdetect_zero_crossing(y_axis, x_axis=None, window=5):
 
 
 def _smooth(x, window_len=11, window='hanning'):
-    """
-    smooth the data using a window of the requested size.
+    """Smooth the data using a window of the requested size.
 
     This method is based on the convolution of a scaled window on the signal.
     The signal is prepared by introducing reflected copies of the signal
@@ -663,7 +681,7 @@ def _smooth(x, window_len=11, window='hanning'):
     if window_len < 3:
         return x
 
-    if not window in ['flat', 'hanning', 'hamming', 'bartlett', 'blackman']:
+    if window not in ['flat', 'hanning', 'hamming', 'bartlett', 'blackman']:
         raise ValueError
 
     s = np.r_[x[window_len - 1:0:-1], x, x[-1:-window_len:-1]]
@@ -678,11 +696,11 @@ def _smooth(x, window_len=11, window='hanning'):
 
 
 def zero_crossings(y_axis, window=11):
-    """
+    """Zero crossing peak detect.
+
     Algorithm to find zero crossings. Smoothens the curve and finds the
     zero-crossings by looking for a sign change.
 
-
     keyword arguments:
     y_axis -- A list containg the signal over which to find zero-crossings
     window -- the dimension of the smoothing window; should be an odd integer
@@ -703,7 +721,7 @@ def zero_crossings(y_axis, window=11):
     indices = [x_axis[index] for index in zero_crossings]
 
     # check if zero-crossings are valid
-    diff = np.diff(indices)
+    # diff = np.diff(indices)
 #    if diff.std() / diff.mean() > 0.2:
 #        print diff.std() / diff.mean()
 #        print np.diff(indices)
